==> financial-front-2.0.1.tar.gz: financial-front-2.0.1/app/controllers/partners_controller.rb <==
# -*- coding: utf-8 -*-

# Netsphere Financial Front / ネットスフィア経理フロント
# Copyright (C) 2007-2009,2011 HORIKAWA Hisashi. All rights reserved.
#     http://www.nslabs.jp/bside/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


require 'upload_module'
require 'partner_search_box'

# 取引先
class PartnersController < ApplicationController
  include UploadModule
  before_filter :login_required
  before_filter :role_apar_required
  
  # GETs should be safe (see http://www.w3.org/2001/tag/doc/whenToUseGet.html)
  verify :method => :post, :only => [ :destroy, :create, :update ],
         :redirect_to => { :action => :list }

  # 検索フォームの表示
  def index
  end
  
  def search
    @search = PartnerSearchBox.new(params[:search])
    if !@search.text || @search.text.strip == ''
      @search.errors.add_to_base '検索テキストを入力してください。'
      render :action => 'index'
      return
    end

    @partners = @search.find_by_text
  end


  def show
    @partner = Partner.find params[:id]
    @invoices = {}
    @sales_invoices = {}
    Company.find(:all).each {|company|
      # 請求書リスト
      invs = Invoice.paginate :page => params[:page],
                    :per_page => 20,
                    :conditions => ['partner_id = ? AND company_setting_id = ?', 
                                    @partner.id, company.id],
                    :order => 'buy_day DESC, id'
      @invoices[company.id] = invs if invs.size > 0
      invs = SalesInvoice.paginate :page => params[:sipage],
                    :per_page => 20,
                    :conditions => ['partner_id = ? AND company_setting_id = ?', 
                                    @partner.id, company.id],
                    :order => 'sell_day DESC, si_number'
      @sales_invoices[company.id] = invs if invs.size > 0
    }
  end

  def new
    @partner = Partner.new
  end
  
  # 10刻みで加算する
  def get_next_zaimu_id
    cs = GlobalSetting.find :first
    raise if !cs
    while Partner.find_by_zaimu_id(cs.partner_counter)
      cs.partner_counter += 10 - (cs.partner_counter % 10)
    end
    r = cs.partner_counter
    cs.partner_counter += 10
    cs.save!
    return r
  end
  private :get_next_zaimu_id
  
  # 新しく作成
  def create
    @partner = Partner.new params[:partner]
    @partner.zaimu_id = get_next_zaimu_id() if @partner.zaimu_id.to_i == 0
    @partner.created_by = current_user
    @partner.updated_by = current_user
    if @partner.save
      flash[:notice] = '取引先は、正常に作成されました。'
      redirect_to :action => 'show', :id => @partner
    else
      render :action => 'new'
    end
  end
  
  # 編集画面の表示
  def edit
    @partner = Partner.find(params[:id])
  end
  
  # 更新
  def update
    @partner = Partner.find(params[:id])
    @partner.updated_by = current_user
    if @partner.update_attributes(params[:partner])
      flash[:notice] = 'Partner was successfully updated.'
      redirect_to :action => 'show', :id => @partner
    else
      render :action => 'edit'
    end
  end

  def destroy
    partner = Partner.find(params[:id])
    s =  "取引先 #{partner.name} は、正常に削除されました。"
    partner.destroy
    flash[:notice] = s
    redirect_to :action => 'index'
  end
end

==> financial-front-2.99.0.tar.gz: financial-front-2.99.0/app/controllers/partners_controller.rb <==
# -*- coding: utf-8 -*-

# Netsphere Financial Front / ネットスフィア経理フロント
# Copyright (C) 2007-2009,2011 HORIKAWA Hisashi. All rights reserved.
#     http://www.nslabs.jp/bside/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


require 'upload_module'
require 'partner_search_box'

# 取引先
class PartnersController < ApplicationController
  include UploadModule
  before_filter :login_required
  before_filter :role_apar_required
  
  # GETs should be safe (see http://www.w3.org/2001/tag/doc/whenToUseGet.html)
  verify :method => :post, :only => [ :destroy, :create, :update ],
         :redirect_to => { :action => :list }

  # 検索フォームの表示
  def index
  end
  
  def search
    @search = PartnerSearchBox.new(params[:search])
    if !@search.text || @search.text.strip == ''
      @search.errors.add_to_base '検索テキストを入力してください。'
      render :action => 'index'
      return
    end

    @partners = @search.find_by_text
  end


  def show
    @partner = Partner.find params[:id]
    @invoices = {}
    @sales_invoices = {}

    current_user.accessible_companies.each {|company|
      # 請求書リスト
      invs = Invoice.paginate :page => params[:page],
                    :per_page => 20,
                    :conditions => ['partner_id = ? AND company_setting_id = ?', 
                                    @partner.id, company.id],
                    :order => 'buy_day DESC, id'
      @invoices[company.id] = invs if invs.size > 0
      invs = SalesInvoice.paginate :page => params[:sipage],
                    :per_page => 20,
                    :conditions => ['partner_id = ? AND company_setting_id = ?', 
                                    @partner.id, company.id],
                    :order => 'sell_day DESC, si_number'
      @sales_invoices[company.id] = invs if invs.size > 0
    }
  end

  def new
    @partner = Partner.new
  end
  
  # 10刻みで加算する
  def get_next_zaimu_id
    cs = GlobalSetting.find :first
    raise if !cs
    while Partner.find_by_zaimu_id(cs.partner_counter)
      cs.partner_counter += 10 - (cs.partner_counter % 10)
    end
    r = cs.partner_counter
    cs.partner_counter += 10
    cs.save!
    return r
  end
  private :get_next_zaimu_id
  
  # 新しく作成
  def create
    @partner = Partner.new params[:partner]
    @partner.zaimu_id = get_next_zaimu_id() if @partner.zaimu_id.to_i == 0
    @partner.created_by = current_user
    @partner.updated_by = current_user
    if @partner.save
      flash[:notice] = '取引先は、正常に作成されました。'
      redirect_to :action => 'show', :id => @partner
    else
      render :action => 'new'
    end
  end
  
  # 編集画面の表示
  def edit
    @partner = Partner.find(params[:id])
  end
  
  # 更新
  def update
    @partner = Partner.find(params[:id])
    @partner.updated_by = current_user
    if @partner.update_attributes(params[:partner])
      flash[:notice] = 'Partner was successfully updated.'
      redirect_to :action => 'show', :id => @partner
    else
      render :action => 'edit'
    end
  end

  def destroy
    @partner = Partner.find params[:id]
    @invoices = {}
    @sales_invoices = {}

    s =  "取引先 #{@partner.name} は、正常に削除されました。"
    begin
      @partner.destroy
    rescue ActiveRecord::InvalidForeignKey => e
      @error = e.to_s
      render :action => "show", :id => @partner
      return
    end
    flash[:notice] = s
    redirect_to :action => 'index'
  end
end
